@@ -1,34 +1,31 @@
-from typing import List
 
-import pytest
-
-import vdocipher
 from vdocipher import Video
+from vdocipher.tests.conftest import BaseTest
 
 
-class TestVideo:
+class TestVideo(BaseTest):
 
-    def test_video_get_list(self, vdocipher, ):
-        videos = vdocipher.Video().get_list()
+    def test_video_get_list(self):
+        videos = self.vdocipher.Video().get_list()
 
         assert len(videos) > 0
         [isinstance(video_obj, Video) for video_obj in videos[:5]]
 
-    def test_video_get_list_pagination(self, vdocipher):
-        video_list = [vdocipher.Video(title=f'test {i}').upload('resources/test_file.mp4') for i in range(3)]
+    def test_video_get_list_pagination(self):
+        video_list = [self.vdocipher.Video(title=f'test {i}').upload('resources/test_file.mp4') for i in range(3)]
 
         number_page = 1
         page_limit = 2
 
-        videos = vdocipher.Video().get_list(number_page, page_limit)
+        videos = self.vdocipher.Video().get_list(number_page, page_limit)
 
         assert len(videos) <= page_limit
         [isinstance(video_obj, Video) for video_obj in videos]
 
         [video.delete() for video in video_list]
 
-    def test_video_upload_credentials(self, vdocipher):
-        upload_credentials = vdocipher.UploadCredentials().create(title='test')
+    def test_video_upload_credentials(self):
+        upload_credentials = self.vdocipher.UploadCredentials().create(title='test')
 
         assert upload_credentials.video_id
         assert upload_credentials.client_payload.uploadLink
@@ -39,7 +36,7 @@ class TestVideo:
         assert upload_credentials.client_payload.key
         assert upload_credentials.client_payload.policy
 
-        vdocipher.Video(id=upload_credentials.video_id).delete()
+        self.vdocipher.Video(id=upload_credentials.video_id).delete()
 
     def test_video_upload(self, video: Video):
         assert isinstance(video, Video)
@@ -51,8 +48,8 @@ class TestVideo:
         assert response.status_code == 200
         assert "Successfully deleted 1 videos" in response.json()['message']
 
-    def test_delete(self,vdocipher):
-        videos_to_test = vdocipher.Video(id='cfc80862639d45ba8ade5b0b90332f44').delete()
+    def test_delete(self):
+        videos_to_test = self.vdocipher.Video(id='cfc80862639d45ba8ade5b0b90332f44').delete()
 
     def test_video_get(self, video):
         video_obj = video.get()
@@ -61,11 +58,11 @@ class TestVideo:
         assert video_obj.title == video.title
         assert video_obj.status == 'PRE-Upload'
 
-    def test_video_get_query(self, vdocipher):
-        videos_to_test = [vdocipher.Video(title=f'test-query-{i}').upload('resources/test_file.mp4') for i in range(3)]
+    def test_video_get_query(self):
+        videos_to_test = [self.vdocipher.Video(title=f'test-query-{i}').upload('resources/test_file.mp4') for i in range(3)]
 
         query_test = 'test-query-2'
-        videos_list = vdocipher.Video().query(query=query_test)
+        videos_list = self.vdocipher.Video().query(query=query_test)
 
         assert len(videos_list) > 0
 
